/**
 * @file log.h
 * @brief ログ関係
 * @author BananaJinn
 * @version $Id: log.h,v 1.4 2010/11/01 14:34:11 bananajinn Exp $
 * 円盤複写屋
 * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
 */
#ifndef __LOG_H__
#define __LOG_H__

extern void DebugLog(char *fmt, ...);
extern void DebugDump(void *ptr, size_t size, const char *message);

#endif /* !__LOG_H__ */
